@@ -3,7 +3,7 @@ use std::convert::TryFrom;
 
 use rdkafka::ClientConfig;
 use rlink::core::element::FnSchema;
-use rlink::core::properties::{Properties, FN_NAME, PARALLELISM};
+use rlink::core::properties::{Properties, PARALLELISM};
 
 use crate::buffer_gen::kafka_message;
 use crate::source::deserializer::{
@@ -16,6 +16,7 @@ use crate::{
     TOPICS,
 };
 
+#[derive(Debug)]
 pub struct KafkaInputFormatBuilder {
     fn_name: Option<String>,
     parallelism: u16,
@@ -56,6 +57,8 @@ impl KafkaInputFormatBuilder {
         self,
         deserializer_builder: Option<Box<dyn KafkaRecordDeserializerBuilder>>,
     ) -> KafkaInputFormat {
+        info!("build kafka source with: {:?}", &self);
+
         let mut client_config = ClientConfig::new();
         for (key, val) in &self.conf_map {
             client_config.set(key.as_str(), val.as_str());
@@ -111,9 +114,7 @@ impl TryFrom<Properties> for KafkaInputFormatBuilder {
 
         let mut builder = KafkaInputFormatBuilder::new(client_config, topics, parallelism);
 
-        if let Ok(fn_name) = properties.get_string(FN_NAME) {
-            builder = builder.fn_name(fn_name.as_str());
-        }
+        builder = builder.fn_name(properties.name());
 
         if let Ok(buffer_size) = properties.get_usize(BUFFER_SIZE) {
             builder = builder.buffer_size(buffer_size);
